<?php
namespace Creativecouponcode;

use Creativecouponcode\PageSettings\Page_Settings;
define( "BWDCOD_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDCOD_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );

class ClassBWDCODCouponCode {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdcod_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdcod_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdcod_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdcod_the_coupon_code_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdcod-coupon-code.php' );
	}

	public function bwdcod_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BWDCODCouponCode() );
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/bwdcod-coupon-code-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function bwdcod_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdcod-coupon-code-category',
			[
				'title' => esc_html__( 'BWD Coupon Code', 'bwd-coupon-code' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function bwdcod_all_assets_for_the_public(){
		wp_enqueue_script( 'bwdcod_coupon_code_min_js', plugin_dir_url( __FILE__ ) . 'assets/public/js/min.js', array('jquery'), '1.0', true );

		wp_enqueue_style( 'bwdcod_coupon_font_awesome_css', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.7.2/css/all.min.css', array(), '5.7.2', 'all' );
		
		$all_css_js_file = array(
            'bwdcod_coupon_code_style_css' => array('bwdcod_path_define'=>BWDCOD_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/style.css'),

        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdcod_path_define'], null, '1.0', 'all');
        }
	}
	public function bwdcod_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bwdcod_coupon_code_admin_icon_css' => array('bwdcod_path_admin_define'=>BWDCOD_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdcod_path_admin_define'], null, '1.0', 'all');
        }
	}

	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdcod_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdcod_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdcod_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdcod_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdcod_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
ClassBWDCODCouponCode::instance();